.. currentmodule:: numpy

==========================
NumPy 1.19.4 Release Notes
==========================

NumPy 1.19.4 is a quick release to revert the OpenBLAS library version.  It was
hoped that the 0.3.12 OpenBLAS version used in 1.19.3 would work around the
Microsoft fmod bug, but problems in some docker environments turned up. Instead,
1.19.4 will use the older library and run a sanity check on import, raising an
error if the problem is detected. Microsoft is aware of the problem and has
promised a fix, users should upgrade when it becomes available.

This release supports Python 3.6-3.9

Contributors
============

A total of 1 people contributed to this release.  People with a "+" by their
names contributed a patch for the first time.

* Charles Harris

Pull requests merged
====================

A total of 2 pull requests were merged for this release.

* `#17679 <https://github.com/numpy/numpy/pull/17679>`__: MAINT: Add check for Windows 10 version 2004 bug.
* `#17680 <https://github.com/numpy/numpy/pull/17680>`__: REV: Revert OpenBLAS to 1.19.2 version for 1.19.4
